"""
Manimera Theme Package.

This package manages visual themes, color palettes, and defaultstyles for Manimera animations.
"""

from .colors import MESSAGE_BLUE
from .colors import MESSAGE_GREEN
from .colors import MESSAGE_GREY
from .colors import BACKGROUND_GREY
from .colors import MANIMERA_PINK


__all__ = [
    # Message Colors
    "MESSAGE_BLUE",
    "MESSAGE_GREEN",
    "MESSAGE_GREY",
    # Background Colors
    "BACKGROUND_GREY",
    # Theme Colors
    "MANIMERA_PINK",
]
